Render a shock-balance test as LaTeX or Markdown
Source:R/format_tables.R
format.ssb_shock_balance.RdPaste-ready coefficient table for the [ssb_shock_balance()] test, with the joint Wald statistic in a note.
R/format_tables.R
format.ssb_shock_balance.RdPaste-ready coefficient table for the [ssb_shock_balance()] test, with the joint Wald statistic in a note.